# sixrunr [![Version][version-badge]][version-link] ![MIT License][license-badge]


Run cwl piplines downloaded from sixoclock(www.sixoclock.net)


`sixrunr` 是一个本地运行cwl流程的python库


### 示例




### 使用方式

```
usage: sixrunr bwa.cwl bwa.yml

```


### 安装

```
$ pip install sixrunr
```


### License

[Apache-2.0 License](https://github.com/6-oclock/sixrunr/blob/master/LICENSE)


[version-badge]:   https://img.shields.io/badge/version-0.1-brightgreen.svg
[version-link]:    https://pypi.python.org/pypi/sixrunr/
[license-badge]:   https://img.shields.io/github/license/pythonml/douyin_image.svg